@@ -8,7 +8,7 @@
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
+ * as published by the Free Software Foundation; either version 3
  * of the License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be
@@ -16,10 +16,8 @@
  * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
  * PURPOSE. See the GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307 USA
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -27,11 +25,11 @@
 #endif
 
 #include <string.h>
+#include "global.h"
 #include "canvas.h"
 #include "image.h"
 #include "debug.h"
-#include "ui.h"
-#include "support.h"
+#include "util.h"
 
 #define MAX_WIDTH  4096
 #define MAX_HEIGHT 4096
@@ -132,7 +130,9 @@ file_save_as_dialog(gpaint_canvas *canvas)
 {
     GtkWidget *dialog;
     gpaint_drawing *drawing = canvas->drawing;
-    
+    gpaint_tool * tool = canvas->active_tool;
+    if (tool && tool->commit_change)
+        tool->commit_change(tool);
     dialog = gtk_file_chooser_dialog_new(_("Save as"),
                                          GTK_WINDOW(canvas->top_level),
                                          GTK_FILE_CHOOSER_ACTION_SAVE,
