@@ -5,7 +5,7 @@
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
+ * as published by the Free Software Foundation; either version 3
  * of the License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be
@@ -13,10 +13,8 @@
  * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
  * PURPOSE. See the GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307 USA
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef __IMAGE_H__
@@ -47,4 +45,5 @@ gpaint_image*  image_from_selection(GdkPixmap *pixmap, gpaint_point_array *pa);
 int            image_flip_x(gpaint_image *image);
 int            image_flip_y(gpaint_image *image);
 int            image_rotate(gpaint_image *image, double radians);
+GdkPixbuf*     image_pixbuf(gpaint_image *image);
 #endif
