@@ -8,7 +8,7 @@
  *          
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
+ * as published by the Free Software Foundation; either version 3
  * of the License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be
@@ -16,10 +16,8 @@
  * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
  * PURPOSE. See the GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307 USA
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -30,7 +28,7 @@
 #include <stdlib.h>
 #include "tool_palette.h"
 #include "debug.h"
-#include "support.h"
+#include "util.h"
 #include "pixmaps.h"
 
 #include <gtk/gtk.h>
@@ -134,7 +132,7 @@ static void filled_button_destroy(gpaint_fill_button *fb);
 GtkWidget*
 lookup_tool_palette(GtkWidget *widget)
 {
-    GtkWidget *tp = lookup_widget(widget, "table4");
+    GtkWidget *tp = lookup_widget(widget, "tool_palette_table");
     g_assert(tp);
     return tp;
 }
@@ -253,8 +251,9 @@ on_tool_button_realize                 (GtkWidget       *widget,
     }
     else
     {
-	g_warning("missing icon data");
+	    g_warning("missing icon data");
     }
+    
 }
 
 static void
@@ -507,3 +506,16 @@ tool_hash_compare(gconstpointer a, gconstpointer b)
 {
     return (!strcmp((const char*)a, (const char*)b));
 }
+
+
+void tool_palette_set_active_button(GtkWidget *widget, const char *button_name)
+{
+    
+    GtkWidget *button = lookup_widget(widget, button_name);
+    gpaint_tool_button *tb = 
+        (gpaint_tool_button*)gtk_object_get_data(GTK_OBJECT(button), "tool_button");
+    
+    on_tool_select(tb);
+
+
+}
